@@ -433,7 +433,8 @@ def DrawGraph(self, QtGui):
                 y=(data.Ysize-(t*data.Yscale_Sleep_Pattern*3/40))+10
                 paint.setPen(QtGui.QColor(255, 255, 255, 200))
 #                paint.drawLine(1, y-17, data.GraphBitMapLen, y-17)  #Trigger line
-                x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)-data.Derivation*Xscale
+                if(data.QuickMode==False): x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)-data.Derivation*Xscale
+                else: x0=0
                 x00=(x0-GraphStart_index)/Xscale
                 x00=min(x00, data.GraphBitMapLen-40)
                 paint.drawLine(x00, y-17, data.GraphBitMapLen, y-17)  #Trigger line
